@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8":[13,0,89,3],
+"structLV__MAP__COEFF__COST.html#ad30ba41c53bce80c8f4c06a966a71204":[13,0,89,1],
 "structLV__MAP__EOB__COST.html":[13,0,90],
 "structLV__MAP__EOB__COST.html#a8e0e53ae7c9736000019c611ef5eb580":[13,0,90,0],
 "structMBMIExtFrameBufferInfo.html":[13,0,99],
@@ -223,6 +225,7 @@ var NAVTREEINDEX7 =
 "structRateControlCfg.html#a2a4a63fa0ffab9e07d22dc6358e82aeb":[13,0,113,11],
 "structRateControlCfg.html#a3ac7cb9b5858e0ddde6daa99b266f31f":[13,0,113,5],
 "structRateControlCfg.html#a52f9ec528bd34cb6a47dd35ad84e684f":[13,0,113,9],
+"structRateControlCfg.html#a544aae8d6d84faad98234f65bf53e3e8":[13,0,113,19],
 "structRateControlCfg.html#a59b9ae349f79f214c92aa8592831d146":[13,0,113,18],
 "structRateControlCfg.html#a84b4d4494d2f12a98fd4ce19c0705cf4":[13,0,113,2],
 "structRateControlCfg.html#aad5f6c5460396bac864104d259c881ab":[13,0,113,4],
@@ -246,8 +249,5 @@ var NAVTREEINDEX7 =
 "structRefreshFrameInfo.html#aad657d56c2e3c9cb3f54a3aa9c9e1ea2":[13,0,115,1],
 "structRefreshFrameInfo.html#abda267747d6fc4a0be09eaa6b43f636c":[13,0,115,0],
 "structRefreshFrameInfo.html#af43c353c062e7a0046486cce3d82fa5f":[13,0,115,2],
-"structResizeCfg.html":[13,0,116],
-"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197":[13,0,116,1],
-"structResizeCfg.html#a88f92c8f849f948f7794ba230ed52a25":[13,0,116,2],
-"structResizeCfg.html#adb8460d8997975048cd64a44b37fb1ea":[13,0,116,0]
+"structResizeCfg.html":[13,0,116]
 };
