@@ -1,5 +1,8 @@
 var NAVTREEINDEX8 =
 {
+"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197":[13,0,116,1],
+"structResizeCfg.html#a88f92c8f849f948f7794ba230ed52a25":[13,0,116,2],
+"structResizeCfg.html#adb8460d8997975048cd64a44b37fb1ea":[13,0,116,0],
 "structResizePendingParams.html":[13,0,117],
 "structResizePendingParams.html#a32ee46e7d8f1b44501c388351cbb93c1":[13,0,117,0],
 "structResizePendingParams.html#a51e85984e709e2268fc76acc7505dcd1":[13,0,117,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX8 =
 "structaom__codec__enc__cfg.html#a8349dcee2119c7fb3fd15a0ae6fdcf12":[12,0,1,5,6],
 "structaom__codec__enc__cfg.html#a8695946812f24f3719aed80cff00aa29":[12,0,1,5,29],
 "structaom__codec__enc__cfg.html#a877936e8a60207e7eac223811af0c124":[12,0,1,5,40],
-"structaom__codec__enc__cfg.html#a8f3763485bb1f6eea6466b2fe0da2304":[12,0,1,5,11],
-"structaom__codec__enc__cfg.html#a8f8851455e06db026022d4b01671b122":[12,0,1,5,28],
-"structaom__codec__enc__cfg.html#a9217f81f33c62161df9d94e42f2b77c6":[12,0,1,5,19],
-"structaom__codec__enc__cfg.html#aa4d9838419e94e634a02d710da06c842":[12,0,1,5,33]
+"structaom__codec__enc__cfg.html#a8f3763485bb1f6eea6466b2fe0da2304":[12,0,1,5,11]
 };
